#At file:///home/cbell/source/bzr/mysql-6.0-bug-34690/ based on revid:jorgen.loland@stripped
2866 Chuck Bell 2009-08-30
BUG#34960 : Error messages contain the word "meta-data"
Some of the code, test, and error messages in the backup
system do not use the correct spelling of 'metadata'.
This patch makes the code, tests, and error messages for
backup conform to the correct form spelled 'metadata'.
@ mysql-test/suite/backup/r/backup_errors.result
Corrected error message in result file for correct spelling of metadata.
@ mysql-test/suite/backup/r/backup_errors_compression.result
Corrected error message in result file for correct spelling of metadata.
@ mysql-test/suite/backup/r/backup_security.result
Corrected error message in result file for correct spelling of metadata.
@ mysql-test/suite/backup/r/backup_views.result
Corrected error message in result file for correct spelling of metadata.
@ mysql-test/suite/backup/t/backup_charsets.test
Corrected documentation in test file for correct spelling of metadata.
@ mysql-test/suite/backup/t/backup_objects_dependency.test
Corrected suppression in test file for correct spelling of metadata.
@ mysql-test/suite/backup/t/backup_stream_errors.test
Corrected documentation in test file for correct spelling of metadata.
@ sql/backup/backup_info.h
Corrected documentation in source file for correct spelling of metadata.
@ sql/backup/image_info.h
Corrected documentation in source file for correct spelling of metadata.
@ sql/backup/kernel.cc
Corrected documentation in source file for correct spelling of metadata.
Corrected debug synch point in source file for correct spelling of metadata
@ sql/backup/stream_v1.c
Corrected documentation in source file for correct spelling of metadata.
@ sql/share/errmsg-utf8.txt
Corrected documentation in source file for correct spelling of metadata.
@ sql/share/errmsg.txt
Corrected documentation in source file for correct spelling of metadata.
modified:
mysql-test/suite/backup/r/backup_errors.result
mysql-test/suite/backup/r/backup_errors_compression.result
mysql-test/suite/backup/r/backup_security.result
mysql-test/suite/backup/r/backup_views.result
mysql-test/suite/backup/t/backup_charsets.test
mysql-test/suite/backup/t/backup_objects_dependency.test
mysql-test/suite/backup/t/backup_stream_errors.test
sql/backup/backup_info.h
sql/backup/image_info.h
sql/backup/kernel.cc
sql/backup/stream_v1.c
sql/share/errmsg-utf8.txt
sql/share/errmsg.txt
=== modified file 'mysql-test/suite/backup/r/backup_errors.result'
--- a/mysql-test/suite/backup/r/backup_errors.result 2009-03-10 10:02:06 +0000
+++ b/mysql-test/suite/backup/r/backup_errors.result 2009-08-30 22:59:10 +0000
@@ -317,7 +317,7 @@ delete database files so that check_db_d
si_objects.cc @ DatabaseObj::do_serialize
SET DEBUG_SYNC='now SIGNAL db_will_fail';
Database has been deleted, backup will fail
-ERROR HY000: Failed to obtain meta-data for database `db1`
+ERROR HY000: Failed to obtain metadata for database `db1`
Test that backup fails with error if a table used by
a trigger cannot be opened
@@ -330,7 +330,7 @@ SELECT notes FROM mysql.backup_progress;
notes
starting
running
-Failed to obtain meta-data for database `db1`
+Failed to obtain metadata for database `db1`
error
DROP DATABASE IF EXISTS db1;
CREATE DATABASE db1;
@@ -346,7 +346,7 @@ trigger metadata
PURGE BACKUP LOGS;
SET SESSION DEBUG='+d,backup_fail_add_trigger';
BACKUP DATABASE db1 TO 'bup_db1.bak' ;
-ERROR HY000: Failed to obtain meta-data for trigger `db1`.`trg`
+ERROR HY000: Failed to obtain metadata for trigger `db1`.`trg`
verify backup history and progress logs:
SELECT backup_state,operation, backup_file,command FROM mysql.backup_history;
backup_state operation backup_file command
@@ -355,7 +355,7 @@ SELECT notes FROM mysql.backup_progress;
notes
starting
running
-Failed to obtain meta-data for trigger `db1`.`trg`
+Failed to obtain metadata for trigger `db1`.`trg`
error
SET DEBUG_SYNC= 'reset';
DROP DATABASE db1;
@@ -530,7 +530,7 @@ SET SESSION DEBUG='-d';
#
SET SESSION DEBUG='+d,restore_read_meta_data';
RESTORE FROM 'errorinject.bak';
-ERROR HY000: Error when reading meta-data
+ERROR HY000: Error when reading metadata
SET SESSION DEBUG='-d';
DROP DATABASE db1;
#
=== modified file 'mysql-test/suite/backup/r/backup_errors_compression.result'
--- a/mysql-test/suite/backup/r/backup_errors_compression.result 2009-03-10 10:02:06 +0000
+++ b/mysql-test/suite/backup/r/backup_errors_compression.result 2009-08-30 22:59:10 +0000
@@ -317,7 +317,7 @@ delete database files so that check_db_d
si_objects.cc @ DatabaseObj::do_serialize
SET DEBUG_SYNC='now SIGNAL db_will_fail';
Database has been deleted, backup will fail
-ERROR HY000: Failed to obtain meta-data for database `db1`
+ERROR HY000: Failed to obtain metadata for database `db1`
Test that backup fails with error if a table used by
a trigger cannot be opened
@@ -330,7 +330,7 @@ SELECT notes FROM mysql.backup_progress;
notes
starting
running
-Failed to obtain meta-data for database `db1`
+Failed to obtain metadata for database `db1`
error
DROP DATABASE IF EXISTS db1;
CREATE DATABASE db1;
@@ -346,7 +346,7 @@ trigger metadata
PURGE BACKUP LOGS;
SET SESSION DEBUG='+d,backup_fail_add_trigger';
BACKUP DATABASE db1 TO 'bup_db1.bak' WITH COMPRESSION;
-ERROR HY000: Failed to obtain meta-data for trigger `db1`.`trg`
+ERROR HY000: Failed to obtain metadata for trigger `db1`.`trg`
verify backup history and progress logs:
SELECT backup_state,operation, backup_file,command FROM mysql.backup_history;
backup_state operation backup_file command
@@ -355,7 +355,7 @@ SELECT notes FROM mysql.backup_progress;
notes
starting
running
-Failed to obtain meta-data for trigger `db1`.`trg`
+Failed to obtain metadata for trigger `db1`.`trg`
error
SET DEBUG_SYNC= 'reset';
DROP DATABASE db1;
@@ -530,7 +530,7 @@ SET SESSION DEBUG='-d';
#
SET SESSION DEBUG='+d,restore_read_meta_data';
RESTORE FROM 'errorinject.bak';
-ERROR HY000: Error when reading meta-data
+ERROR HY000: Error when reading metadata
SET SESSION DEBUG='-d';
DROP DATABASE db1;
#
=== modified file 'mysql-test/suite/backup/r/backup_security.result'
--- a/mysql-test/suite/backup/r/backup_security.result 2009-07-15 19:19:14 +0000
+++ b/mysql-test/suite/backup/r/backup_security.result 2009-08-30 22:59:10 +0000
@@ -332,10 +332,10 @@ GRANT SELECT, EVENT, TRIGGER, BACKUP, RE
# error ER_BACKUP_GET_META_VIEW
#
BACKUP DATABASE backup_test to 'backup_test_select.bak';
-ERROR HY000: Failed to obtain meta-data for view `backup_test`.`v1`
+ERROR HY000: Failed to obtain metadata for view `backup_test`.`v1`
SHOW ERRORS;
Level Code Message
-Error # Failed to obtain meta-data for view `backup_test`.`v1`
+Error # Failed to obtain metadata for view `backup_test`.`v1`
#
# Connect as root and add privileges.
#
=== modified file 'mysql-test/suite/backup/r/backup_views.result'
--- a/mysql-test/suite/backup/r/backup_views.result 2009-03-18 22:01:12 +0000
+++ b/mysql-test/suite/backup/r/backup_views.result 2009-08-30 22:59:10 +0000
@@ -584,7 +584,7 @@ Testing view selecting from altered view
SELECT * FROM alter2;
ERROR HY000: View 'bup_db1.alter2' references invalid table(s) or column(s) or function(s) or definer/invoker of view lack rights to use them
BACKUP DATABASE bup_db1 TO 'bup_alterview.bak';
-ERROR HY000: Failed to obtain meta-data for view `bup_db1`.`alter2`
+ERROR HY000: Failed to obtain metadata for view `bup_db1`.`alter2`
*** EXIT Backup of database with altered view
=== modified file 'mysql-test/suite/backup/t/backup_charsets.test'
--- a/mysql-test/suite/backup/t/backup_charsets.test 2009-05-21 18:12:42 +0000
+++ b/mysql-test/suite/backup/t/backup_charsets.test 2009-08-30 22:59:10 +0000
@@ -17,7 +17,7 @@
#
# - Test more character sets.
# - Test that native backup engines are not confuced by extended charsets.
-# - Test that all meta-data stored in backup image is always handled correctly
+# - Test that all metadata stored in backup image is always handled correctly
# regardless of character set settings on backup and restore servers.
#
=== modified file 'mysql-test/suite/backup/t/backup_objects_dependency.test'
--- a/mysql-test/suite/backup/t/backup_objects_dependency.test 2009-08-20 18:27:04 +0000
+++ b/mysql-test/suite/backup/t/backup_objects_dependency.test 2009-08-30 22:59:10 +0000
@@ -16,7 +16,7 @@
# Suppress warning about expected backup/restore errors
disable_query_log;
call mtr.add_suppression("Backup: Failed to add view");
-call mtr.add_suppression("Backup: Failed to obtain meta-data for view");
+call mtr.add_suppression("Backup: Failed to obtain metadata for view");
call mtr.add_suppression("Restore: Could not restore view");
call mtr.add_suppression("Backup: Operation aborted");
enable_query_log;
=== modified file 'mysql-test/suite/backup/t/backup_stream_errors.test'
--- a/mysql-test/suite/backup/t/backup_stream_errors.test 2009-01-20 11:36:32 +0000
+++ b/mysql-test/suite/backup/t/backup_stream_errors.test 2009-08-30 22:59:10 +0000
@@ -5,7 +5,7 @@
# branch inside function bstream_write_part(). This is tricky and depends
# very much on the low-level implementation details.
#
-# The problem is triggered when BACKUP writes meta-data section of backup
+# The problem is triggered when BACKUP writes metadata section of backup
# image. More precisely, when writing the data chunk containing definitions
# of per-database objects (stored procedures in this case). The definitions
# have to be written in well designed stages to force internal buffering
@@ -13,7 +13,7 @@
#
# Here is what must happen:
#
-# 1. Several procedures are stored such that the size of their meta-data
+# 1. Several procedures are stored such that the size of their metadata
# do not exceed MIN_WRITE_SIZE constant (currently 1024 bytes). This is
# so that definition of each procedure is not directly written to the stream
# but rather stored in the output buffer.
@@ -23,9 +23,9 @@
# chunk fragments and there are certain limits on possible sizes of such a
# fragment - see sql/backup/stream_v1_transport.c for some details).
#
-# 3. Now BACKUP should write meta-data entry whose size is bigger than
+# 3. Now BACKUP should write metadata entry whose size is bigger than
# MIN_WRITE_SIZE (to force direct write to the output stream) but such that
-# the total length of all meta-data entries written so far should not exceed
+# the total length of all metadata entries written so far should not exceed
# 2*4k. This will force the internal buffering logic to follow the incorrect
# execution path:
#
=== modified file 'sql/backup/backup_info.h'
--- a/sql/backup/backup_info.h 2008-12-18 21:46:36 +0000
+++ b/sql/backup/backup_info.h 2009-08-30 22:59:10 +0000
@@ -59,7 +59,7 @@ private:
THD *m_thd;
- class Global_iterator; ///< Iterates over global items (for which meta-data is stored).
+ class Global_iterator; ///< Iterates over global items (for which metadata is stored).
class Perdb_iterator; ///< Iterates over all per-database objects (except tables).
/// State of the info structure.
=== modified file 'sql/backup/image_info.h'
--- a/sql/backup/image_info.h 2009-08-21 15:43:19 +0000
+++ b/sql/backup/image_info.h 2009-08-30 22:59:10 +0000
@@ -40,7 +40,7 @@ class Logical_snapshot;
all objects stored in it (currently only databases and tables).
Only object names are stored in the catalogue. Other object data is stored
- in the meta-data part of the image and in case of tables, their data is
+ in the metadata part of the image and in case of tables, their data is
stored in table data snapshots created by backup drivers.
For each snapshot present in the image there is a @c Snapshot_info object.
=== modified file 'sql/backup/kernel.cc'
--- a/sql/backup/kernel.cc 2009-08-21 15:43:19 +0000
+++ b/sql/backup/kernel.cc 2009-08-30 22:59:10 +0000
@@ -54,7 +54,7 @@
@todo Use internal table name representation when passing tables to
backup/restore drivers.
- @todo Handle other types of meta-data in Backup_info methods.
+ @todo Handle other types of metadata in Backup_info methods.
@todo Handle item dependencies when adding new items.
@todo Handle other kinds of backup locations (far future).
*/
@@ -613,7 +613,7 @@ int Backup_restore_ctx::prepare(::String
if (!mem_alloc)
return fatal_error(report_error(ER_OUT_OF_RESOURCES));
- // Freeze all meta-data.
+ // Freeze all metadata.
DEBUG_SYNC(m_thd, "before_backup_ddl_block");
ret= obs::bml_get(m_thd);
@@ -638,7 +638,7 @@ int Backup_restore_ctx::prepare(::String
@note This function reports errors.
- @note It is important that changes of meta-data are blocked as part of the
+ @note It is important that changes of metadata are blocked as part of the
preparations. The set of server objects and their definitions should not
change after the backup context has been prepared and before the actual backup
is performed using @c do_backup() method.
@@ -672,7 +672,7 @@ Backup_restore_ctx::prepare_for_backup(S
/*
Do preparations common to backup and restore operations. After call
- to prepare() all meta-data changes are blocked.
+ to prepare() all metadata changes are blocked.
*/
DEBUG_SYNC(m_thd, "before_backup_common_prepare");
if (prepare(backupdir, orig_loc)) // Logs errors and detects interruptions
@@ -810,7 +810,7 @@ Backup_restore_ctx::prepare_for_restore(
/*
Do preparations common to backup and restore operations. After this call
- changes of meta-data are blocked.
+ changes of metadata are blocked.
*/
DEBUG_SYNC(m_thd, "before_restore_common_prepare");
if (prepare(backupdir, orig_loc))
@@ -1060,7 +1060,7 @@ void Backup_restore_ctx::unlock_tables()
This should reverse all settings made when context was created and prepared.
If it was requested, the backup/restore location is removed. Also, the backup
stream memory allocator is shut down. Any other allocated resources are
- deleted in the destructor. Changes to meta-data are unblocked.
+ deleted in the destructor. Changes to metadata are unblocked.
@returns 0 or error code if error was detected.
@@ -1131,7 +1131,7 @@ int Backup_restore_ctx::close()
// unlock tables if they are still locked
unlock_tables(); // Never errors
- // unfreeze meta-data
+ // unfreeze metadata
obs::bml_release(); // Never errors
// restore thread options
@@ -1414,7 +1414,7 @@ int Backup_restore_ctx::do_restore(bool
if (report_killed())
DBUG_RETURN(fatal_error(ER_QUERY_INTERRUPTED));
- DBUG_PRINT("restore", ("Restoring meta-data"));
+ DBUG_PRINT("restore", ("Restoring metadata"));
// unless RESTORE... OVERWRITE: return error if database already exists
if (!overwrite)
@@ -2083,7 +2083,7 @@ void bcat_db_iterator_free(st_bstream_i
/*****************************************************************
- Services for backup stream library related to meta-data
+ Services for backup stream library related to metadata
manipulation.
*****************************************************************/
@@ -2318,9 +2318,9 @@ int bcat_get_item_create_query(st_bstrea
}
/**
- Get extra meta-data (if any) for a given object.
+ Get extra metadata (if any) for a given object.
- @note Extra meta-data is not used currently.
+ @note Extra metadata is not used currently.
*/
extern "C"
int bcat_get_item_create_data(st_bstream_image_header *catalogue,
=== modified file 'sql/backup/stream_v1.c'
--- a/sql/share/errmsg-utf8.txt 2009-08-05 15:13:12 +0000
+++ b/sql/share/errmsg-utf8.txt 2009-08-30 22:59:10 +0000
@@ -6267,11 +6267,11 @@ ER_BACKUP_CREATE_RESTORE_DRIVER
ER_BACKUP_TOO_MANY_IMAGES
eng "Backup image uses %d backup engines but maximum %d are supported"
ER_BACKUP_WRITE_META
- eng "Error when saving meta-data of %-.64s"
+ eng "Error when saving metadata of %-.64s"
ER_BACKUP_READ_META
- eng "Error when reading meta-data"
+ eng "Error when reading metadata"
ER_BACKUP_CREATE_META
- eng "Failed to obtain meta-data for %-.64s"
+ eng "Failed to obtain metadata for %-.64s"
ER_BACKUP_GET_BUF
eng "Can't allocate buffer for image data transfer"
ER_BACKUP_WRITE_DATA
@@ -6379,17 +6379,17 @@ ER_BACKUP_WRITE_SUMMARY
ER_BACKUP_READ_SUMMARY
eng "Error when reading summary section of backup image"
ER_BACKUP_GET_META_DB
- eng "Failed to obtain meta-data for database %-.64s"
+ eng "Failed to obtain metadata for database %-.64s"
ER_BACKUP_GET_META_TABLE
- eng "Failed to obtain meta-data for table %-.64s"
+ eng "Failed to obtain metadata for table %-.64s"
ER_BACKUP_GET_META_VIEW
- eng "Failed to obtain meta-data for view %-.64s"
+ eng "Failed to obtain metadata for view %-.64s"
ER_BACKUP_GET_META_SROUT
- eng "Failed to obtain meta-data for stored routine %-.64s"
+ eng "Failed to obtain metadata for stored routine %-.64s"
ER_BACKUP_GET_META_EVENT
- eng "Failed to obtain meta-data for event %-.64s"
+ eng "Failed to obtain metadata for event %-.64s"
ER_BACKUP_GET_META_TRIGGER
- eng "Failed to obtain meta-data for trigger %-.64s"
+ eng "Failed to obtain metadata for trigger %-.64s"
ER_BACKUP_CREATE_BE
eng "Cannot create backup engine for storage engine %-.64s"
ER_BACKUP_LIST_PERDB
@@ -6415,7 +6415,7 @@ ER_BACKUP_CANT_RESTORE_TS
ER_BACKUP_TS_CHANGE
eng "Tablespace %-.64s needed by tables being restored, but the current tablespace definition differs from how it was when backup was made."
ER_BACKUP_GET_META_TS
- eng "Failed to obtain meta-data for tablespace %-.64s."
+ eng "Failed to obtain metadata for tablespace %-.64s."
ER_TABLESPACE_DATAFILE_EXIST
eng "Tablespace data file '%-.192s' already exists"
ER_BACKUP_CATALOG_ADD_TS
@@ -6445,7 +6445,7 @@ ER_BACKUP_LIST_DB_PRIV
ER_BACKUP_CATALOG_ADD_PRIV
eng "Failed to add grant '%-.64s' to the catalog"
ER_BACKUP_GET_META_PRIV
- eng "Failed to obtain meta-data for grant '%-.64s'."
+ eng "Failed to obtain metadata for grant '%-.64s'."
ER_BACKUP_CANT_RESTORE_PRIV
eng "Could not execute grant '%-.64s'."
ER_BACKUP_GRANT_SKIPPED
=== modified file 'sql/share/errmsg.txt'
--- a/sql/share/errmsg.txt 2009-08-05 15:13:12 +0000
+++ b/sql/share/errmsg.txt 2009-08-30 22:59:10 +0000
@@ -6267,11 +6267,11 @@ ER_BACKUP_CREATE_RESTORE_DRIVER
ER_BACKUP_TOO_MANY_IMAGES
eng "Backup image uses %d backup engines but maximum %d are supported"
ER_BACKUP_WRITE_META
- eng "Error when saving meta-data of %-.64s"
+ eng "Error when saving metadata of %-.64s"
ER_BACKUP_READ_META
- eng "Error when reading meta-data"
+ eng "Error when reading metadata"
ER_BACKUP_CREATE_META
- eng "Failed to obtain meta-data for %-.64s"
+ eng "Failed to obtain metadata for %-.64s"
ER_BACKUP_GET_BUF
eng "Can't allocate buffer for image data transfer"
ER_BACKUP_WRITE_DATA
@@ -6379,17 +6379,17 @@ ER_BACKUP_WRITE_SUMMARY
ER_BACKUP_READ_SUMMARY
eng "Error when reading summary section of backup image"
ER_BACKUP_GET_META_DB
- eng "Failed to obtain meta-data for database %-.64s"
+ eng "Failed to obtain metadata for database %-.64s"
ER_BACKUP_GET_META_TABLE
- eng "Failed to obtain meta-data for table %-.64s"
+ eng "Failed to obtain metadata for table %-.64s"
ER_BACKUP_GET_META_VIEW
- eng "Failed to obtain meta-data for view %-.64s"
+ eng "Failed to obtain metadata for view %-.64s"
ER_BACKUP_GET_META_SROUT
- eng "Failed to obtain meta-data for stored routine %-.64s"
+ eng "Failed to obtain metadata for stored routine %-.64s"
ER_BACKUP_GET_META_EVENT
- eng "Failed to obtain meta-data for event %-.64s"
+ eng "Failed to obtain metadata for event %-.64s"
ER_BACKUP_GET_META_TRIGGER
- eng "Failed to obtain meta-data for trigger %-.64s"
+ eng "Failed to obtain metadata for trigger %-.64s"
ER_BACKUP_CREATE_BE
eng "Cannot create backup engine for storage engine %-.64s"
ER_BACKUP_LIST_PERDB
@@ -6415,7 +6415,7 @@ ER_BACKUP_CANT_RESTORE_TS
ER_BACKUP_TS_CHANGE
eng "Tablespace %-.64s needed by tables being restored, but the current tablespace definition differs from how it was when backup was made."
ER_BACKUP_GET_META_TS
- eng "Failed to obtain meta-data for tablespace %-.64s."
+ eng "Failed to obtain metadata for tablespace %-.64s."
ER_TABLESPACE_DATAFILE_EXIST
eng "Tablespace data file '%-.192s' already exists"
ER_BACKUP_CATALOG_ADD_TS
@@ -6445,7 +6445,7 @@ ER_BACKUP_LIST_DB_PRIV
ER_BACKUP_CATALOG_ADD_PRIV
eng "Failed to add grant '%-.64s' to the catalog"
ER_BACKUP_GET_META_PRIV
- eng "Failed to obtain meta-data for grant '%-.64s'."
+ eng "Failed to obtain metadata for grant '%-.64s'."
ER_BACKUP_CANT_RESTORE_PRIV
eng "Could not execute grant '%-.64s'."
ER_BACKUP_GRANT_SKIPPED
Attachment: [text/bzr-bundle] bzr/charles.bell@sun.com-20090830225910-te0a93z9jh62amuz.bundle
| Thread |
|---|
| • bzr commit into mysql-6.0-backup branch (charles.bell:2866) Bug#34960 | Chuck Bell | 31 Aug |
--- a/sql/backup/stream_v1.c 2009-06-30 20:37:35 +0000
+++ b/sql/backup/stream_v1.c 2009-08-30 22:59:10 +0000
@@ -560,7 +560,7 @@ int bstream_rd_image_info(backup_stream
@section catalogue Image catalogue
The catalogue describes what items are stored in the image. Note that it
- doesn't contain any meta-data, only item names and other information needed to
+ doesn't contain any metadata, only item names and other information needed to
identify and select them.
@verbatim
@@ -599,7 +599,7 @@ int bstream_rd_image_info(backup_stream
Following user list is a list of tablespaces used by the tables stored in
the backup image. Only tablespace names are listed here, their definitions
- are stored in the meta-data section.
+ are stored in the metadata section.
@verbatim
[tablespaces]= [ ts name ! ... ! ts name ]
@@ -1154,7 +1154,7 @@ int bstream_rd_db_catalogue(backup_strea
@section meta_data Meta data section
- Meta data section contains meta-data for items which need to be created
+ Meta data section contains metadata for items which need to be created
when restoring data. It is divided into three main parts, storing meta data
for global items, tables and other items (per-db and per-table).
@verbatim
@@ -1162,7 +1162,7 @@ int bstream_rd_db_catalogue(backup_strea
[meta data]= [ global items | tables | other items ]
@endverbatim
- The only global items for which we store meta-data information are tablespaces
+ The only global items for which we store metadata information are tablespaces
and databases. Tablespace definitions should come before database definitions
on the [global items] list.
@@ -1228,7 +1228,7 @@ int bstream_wr_item_def(backup_stream*,
int read_and_create_items(backup_stream *s, struct st_bstream_image_header *cat,
enum enum_bstream_meta_item_kind kind);
/** Write meta-data section of a backup image */
int bstream_wr_meta_data(backup_stream *s, struct st_bstream_image_header *cat)
{
void *iter= NULL, *titer= NULL;
@@ -1349,7 +1349,7 @@ wr_error:
}
/**
- Read backup image meta-data section.
+ Read backup image metadata section.
All items read are created using @c bstream_create_item() function.
@@ -1441,8 +1441,8 @@ int bstream_rd_meta_data(backup_stream *
optional extra data ! optional CREATE statement ]
@endverbatim
- Item meta-data contains a CREATE statement or other data in unspecified format
- or both. [flags] inform about which meta-data elements are present in the
+ Item metadata contains a CREATE statement or other data in unspecified format
+ or both. [flags] inform about which metadata elements are present in the
entry.
@verbatim
@@ -1611,7 +1611,7 @@ int bstream_rd_meta_item(backup_stream *
/**
- Write entry with given item's meta-data.
+ Write entry with given item's metadata.
@param[in] s backup stream.
@param[in] cat image catalogue.
@@ -1674,10 +1674,10 @@ int bstream_wr_item_def(backup_stream *s
}
/**
- Read list of meta-data entries and create the corresponding items.
+ Read list of metadata entries and create the corresponding items.
The entries are read until the end of chunk or 0x00 marker is hit.
- After reading meta-data for each item (CREATE statement and/or extra meta-data)
+ After reading metadata for each item (CREATE statement and/or extra metadata)
the item is created using @c bstream_create_item() function which should be
implemented by the program using this library.
=== modified file 'sql/share/errmsg-utf8.txt'
@@ -1228,7 +1228,7 @@ int bstream_wr_item_def(backup_stream*,
int read_and_create_items(backup_stream *s, struct st_bstream_image_header *cat,
enum enum_bstream_meta_item_kind kind);
-/** Write meta-data section of a backup image */
+/** Write metadata section of a backup image */
int bstream_wr_meta_data(backup_stream *s, struct st_bstream_image_header *cat)
{